dnl jvrand.m4 - check for the presence of the jvrand library
dnl Copyright 2001, 2004  Jochen Voss <voss@seehuhn.de>
dnl $Id: jvrand.m4 5877 2004-08-14 10:57:57Z voss $

dnl JV_LIB_JVRAND([MINIMUM-INTERFACE-VERSION,
dnl                 [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl   Checks for an installed jvrand library with an interface version
dnl   of MINIMUM-INTERFACE-VERSION or above.
dnl   If the header file is found define HAVE_JVRAND_H.
dnl   Execute ACTION-IF-FOUND if a suffiently new version of jvrand
dnl   is found, and execute ACTION-IF-NOT-FOUND else.  The default
dnl   action for the latter case is to print a warning message.
dnl   This macro sets the output variables JVRAND_CFLAGS and JVRAND_LIBS.

AC_DEFUN([JV_LIB_JVRAND], [
  AC_ARG_WITH(jvrand-includedir,
    [  --with-jvrand-includedir[=DIR]
                          special header file location for the jvrand library],[
    case "$withval" in
      yes|no) ;;
      *) JVRAND_CFLAGS="-I$withval" ;;
    esac
  ])

  JVRAND_LIBS="-ljvrand" 
  AC_ARG_WITH(jvrand-libdir,
    [  --with-jvrand-libdir[=DIR]
                          special library location for the jvrand library],[
    case "$withval" in
      yes|no) ;;
      *) JVRAND_LIBS="-L$withval $JVRAND_LIBS" ;;
    esac
  ])

  jv_save_CPPFLAGS="$CPPFLAGS"
  CPPFLAGS="$CPPFLAGS $JVRAND_CFLAGS"
  AC_CHECK_HEADERS(jvrand.h,jvrand_ok=yes,jvrand_ok=no)
  ifelse($1,,true,
  if test "$jvrand_ok" = yes; then
    AC_MSG_CHECKING(for jvrand interface version >= $1)
    AC_EGREP_CPP(jvrand_version_match,
[#include <jvrand.h>
#if JVRAND_INTERFACE_VERSION >= $1
jvrand_version_match
#endif
],
      AC_MSG_RESULT(yes),
      AC_MSG_RESULT(no)
      jvrand_ok=no)
  fi)
  if test "$jvrand_ok" = yes; then
    ifelse($2,,true,$2)
  else
    ifelse($3,,
      ifelse($1,,true,
	AC_MSG_WARN(the installed version of the jvrand library is too old!)),
      $3)
  fi
  CPPFLAGS="$jv_save_CPPFLAGS"

  AC_SUBST(JVRAND_CFLAGS)
  AC_SUBST(JVRAND_LIBS)
])
