/* test-shuffle.c - test shuffling
 *
 * Copyright (C) 2001  Jochen Voss.  */

static const  char  rcsid[] = "$Id: test-shuffle.c 5876 2004-08-14 10:36:54Z voss $";

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>

#include "jvrand.h"
#include "util.h"

static int
compare_int (const void *a, const void *b)
{
  const int *xa = (const int *) a;
  const int *xb = (const int *) b;

  return  (*xa > *xb) - (*xa < *xb);
}

static void
test1 (int *fail)
{
  int  buffer [17];
  int  i;

  printf ("%s: shuffling integers ... ", my_name);
  fflush (NULL);
  
  for (i=0; i<17; ++i)  buffer[i] = i;
  jvrand_shuffle (buffer, 17, sizeof(int));
  qsort (buffer, 17, sizeof(int), compare_int);
  for (i=0; i<17; ++i) {
    if (buffer[i] != i) {
      puts ("FAILED");
      *fail = 1;
      return;
    }
  }
  puts ("passed");
}

static int
compare_char (const void *a, const void *b)
{
  const char *xa = (const char *) a;
  const char *xb = (const char *) b;

  return  (*xa > *xb) - (*xa < *xb);
}

static void
test2 (int *fail)
{
  char  buffer [101];
  int  i;

  printf ("%s: shuffling characters ... ", my_name);
  fflush (NULL);
  
  for (i=0; i<101; ++i)  buffer[i] = i;
  jvrand_shuffle (buffer, 101, sizeof(char));
  qsort (buffer, 101, sizeof(char), compare_char);
  for (i=0; i<101; ++i) {
    if (buffer[i] != i) {
      puts ("FAILED");
      *fail = 1;
      return;
    }
  }
  puts ("passed");
}

static int
test3 (void *client_data)
{
  int  buf [4] = { 1, 2, 3, 4 };
  jvrand_shuffle (buf, 4, sizeof(int));
  return  (buf [0] == 2 && buf [1] == 3 && buf [2] == 4 && buf [3] == 1);
}

int
main (int argc, char **argv)
{
  int  fail = 0;

  init_util (argc, argv);
  jvrand_init ();

  test1 (&fail);
  test2 (&fail);
  binomial_test (test3, NULL, 1/24.0, 0.001, "frequency of permutations", &fail);
  
  return  fail;
}
