/* test-uniform.c - test the uniform distribution
 *
 * Copyright (C) 2001  Jochen Voss.  */

static const  char  rcsid[] = "$Id: test-uniform.c 5876 2004-08-14 10:36:54Z voss $";

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdlib.h>
#include <stdio.h>
#include <float.h>

#include "jvrand.h"
#include "util.h"


static int
test1 (void *client_data)
{
  double  x = jvrand_uniform (0, 100.0e30);
  return  (2 <= x && x < 2+5.0e30);
}

static int
test2 (void *client_data)
{
  double  x = jvrand_uniform (-2, 98);
  return  (7 <= x && x < 12);
}

static int
test3 (void *client_data)
{
  double  x = jvrand_uniform (1, 1+100.0e-6);
  return  (x < 1+5.0e-6);
}

static int
test4 (void *client_data)
{
  double  x = jvrand_uniform (1, 1+100*DBL_EPSILON);
  return  (x < 1+5*DBL_EPSILON);
}

static int
test5 (void *client_data)
{
  double  x = jvrand_uniform (1, 1+4*DBL_EPSILON);
  return  (x < 1+DBL_EPSILON);
}

static int
test6 (void *client_data)
{
  double  x = jvrand_uniform (1, 2);
  return  (1.5 <= x && x < 1.5+1e-4);
}


int
main (int argc, char **argv)
{
  int  fail = 0;
  int  fail2 = 0;

  init_util (argc, argv);
  jvrand_init ();

  binomial_test (test1, NULL, 0.05, 0.0005, "large ranges", &fail);
  binomial_test (test2, NULL, 0.05, 0.0005, "medium ranges", &fail);
  binomial_test (test3, NULL, 0.05, 0.0005, "small ranges", &fail);
  binomial_test (test4, NULL, 0.05, 0.0005,
		 "very small ranges (see README)", &fail2);
  binomial_test (test5, NULL, 0.25, 0.001,
		 "extremely small ranges (see README)", &fail2);
  binomial_test (test6, NULL, 1e-4, 1e-5, "small probabilities", &fail);

  if (fail2)  fprintf (stderr, "some failures ignored\n");
  
  return  fail;
}
